<center><img src="https://raw.githubusercontent.com/colav/colav.github.io/master/img/Logo.png"/></center>

# HunabKu dspace plugin 
This is a dspace plugin and provides data in json parsed from xml.

# Description
You can download information of DSpace from multiples institutions such as udea, univalle, uext, unaula.

# Installation

## Dependencies
Not required

## Package
Write here how to install this plugin
usauly is 

`pip install hunabku_dspace`



# License
BSD-3-Clause License 

# Links
http://colav.udea.edu.co/



